@@ -18,6 +18,9 @@ import (
 	"github.com/miekg/dns"
 )
 
+// APIKeyHeader API key header.
+const APIKeyHeader = "X-Api-Key"
+
 // Client the PowerDNS API client.
 type Client struct {
 	serverName string
@@ -66,6 +69,7 @@ func (c *Client) getAPIVersion(ctx context.Context) (int, error) {
 	}
 
 	var versions []apiVersion
+
 	err = json.Unmarshal(result, &versions)
 	if err != nil {
 		return 0, err
@@ -95,6 +99,7 @@ func (c *Client) GetHostedZone(ctx context.Context, authZone string) (*HostedZon
 	}
 
 	var zone HostedZone
+
 	err = json.Unmarshal(result, &zone)
 	if err != nil {
 		return nil, err
@@ -163,7 +168,7 @@ func (c *Client) joinPath(elem ...string) *url.URL {
 }
 
 func (c *Client) do(req *http.Request) (json.RawMessage, error) {
-	req.Header.Set("X-API-Key", c.apiKey)
+	req.Header.Set(APIKeyHeader, c.apiKey)
 
 	resp, err := c.HTTPClient.Do(req)
 	if err != nil {
@@ -177,6 +182,7 @@ func (c *Client) do(req *http.Request) (json.RawMessage, error) {
 	}
 
 	var msg json.RawMessage
+
 	err = json.NewDecoder(resp.Body).Decode(&msg)
 	if err != nil {
 		if errors.Is(err, io.EOF) {
@@ -190,10 +196,12 @@ func (c *Client) do(req *http.Request) (json.RawMessage, error) {
 	// check for PowerDNS error message
 	if len(msg) > 0 && msg[0] == '{' {
 		var errInfo apiError
+
 		err = json.Unmarshal(msg, &errInfo)
 		if err != nil {
 			return nil, errutils.NewUnmarshalError(req, resp.StatusCode, msg, err)
 		}
+
 		if errInfo.ShortMsg != "" {
 			return nil, fmt.Errorf("error talking to PDNS API: %w", errInfo)
 		}
