@@ -34,6 +34,7 @@ var envTest = tester.NewEnvTest(
 
 func Test_loadCredentials_FromEnv(t *testing.T) {
 	defer envTest.RestoreEnv()
+
 	envTest.ClearEnv()
 
 	_ = os.Setenv(EnvAccessKeyID, "123")
@@ -60,6 +61,7 @@ func Test_loadCredentials_FromEnv(t *testing.T) {
 
 func Test_loadRegion_FromEnv(t *testing.T) {
 	defer envTest.RestoreEnv()
+
 	envTest.ClearEnv()
 
 	_ = os.Setenv(EnvRegion, "foo")
@@ -72,6 +74,7 @@ func Test_loadRegion_FromEnv(t *testing.T) {
 
 func Test_getHostedZoneID_FromEnv(t *testing.T) {
 	defer envTest.RestoreEnv()
+
 	envTest.ClearEnv()
 
 	expectedZoneID := "zoneID"
@@ -82,7 +85,7 @@ func Test_getHostedZoneID_FromEnv(t *testing.T) {
 	require.NoError(t, err)
 
 	hostedZoneID, err := provider.getHostedZoneID(t.Context(), "whatever")
-	require.NoError(t, err, "HostedZoneID")
+	require.NoError(t, err)
 
 	assert.Equal(t, expectedZoneID, hostedZoneID)
 }
@@ -128,6 +131,7 @@ func TestNewDefaultConfig(t *testing.T) {
 	for _, test := range testCases {
 		t.Run(test.desc, func(t *testing.T) {
 			envTest.ClearEnv()
+
 			for key, value := range test.envVars {
 				_ = os.Setenv(key, value)
 			}
@@ -141,11 +145,13 @@ func TestNewDefaultConfig(t *testing.T) {
 
 func TestDNSProvider_Present(t *testing.T) {
 	defer envTest.RestoreEnv()
+
 	envTest.ClearEnv()
 
 	provider := servermock.NewBuilder(
 		func(server *httptest.Server) (*DNSProvider, error) {
 			cfg := aws.Config{
+				HTTPClient:       server.Client(),
 				Credentials:      credentials.NewStaticCredentialsProvider("abc", "123", " "),
 				Region:           "mock-region",
 				BaseEndpoint:     aws.String(server.URL),
@@ -181,7 +187,7 @@ func TestDNSProvider_Present(t *testing.T) {
 	keyAuth := "123456d=="
 
 	err := provider.Present(domain, "", keyAuth)
-	require.NoError(t, err, "Expected Present to return no error")
+	require.NoError(t, err)
 }
 
 func Test_createAWSConfig(t *testing.T) {
@@ -270,6 +276,7 @@ func Test_createAWSConfig(t *testing.T) {
 	for _, test := range testCases {
 		t.Run(test.desc, func(t *testing.T) {
 			defer envTest.RestoreEnv()
+
 			envTest.ClearEnv()
 
 			envTest.Apply(test.env)
